@@ -963,7 +963,6 @@ long render_audio_segment(gint nfiles, gint *from_files, gint to_file, gdouble *
       if (zavel<0.) lseek64(in_fd[track],seekstart[track]-tbytes,SEEK_SET);
 
       bytes_read=read(in_fd[track],in_buff,tbytes);
-      //g_print("read %ld bytes\n",bytes_read);
 
       if (zavel<0.) seekstart[track]-=bytes_read;
 
@@ -1010,7 +1009,7 @@ long render_audio_segment(gint nfiles, gint *from_files, gint to_file, gdouble *
       if (mainw->multitrack!=NULL) {
 	// we work out the "visibility" of each track at tc
 	gdouble *vis=get_track_visibility_at_tc(mainw->multitrack->event_list,nfiles,mainw->multitrack->opts.back_audio_tracks,tc,&shortcut,mainw->multitrack->opts.audio_bleedthru);
-	
+
 	// locate the master volume parameter, and multiply all values by vis[track]
 	weed_apply_audio_effects(mainw->filter_map,chunk_float_buffer,mainw->multitrack->opts.back_audio_tracks,out_achans,blocksize,out_arate,tc,vis);
 	
@@ -1039,7 +1038,7 @@ long render_audio_segment(gint nfiles, gint *from_files, gint to_file, gdouble *
 
       if (mainw->multitrack==NULL) {
 	time+=(gdouble)frames_out/(gdouble)out_arate;
-	opvol=opvol_start+(opvol_end-opvol_start)*(time/((tc_end-tc_start)/U_SEC));
+	opvol=opvol_start+(opvol_end-opvol_start)*(time/(gdouble)((tc_end-tc_start)/U_SEC));
       }
       else tc+=(gdouble)blocksize/(gdouble)out_arate*U_SEC;
     }
@@ -1614,6 +1613,7 @@ void free_pulse_audio_buffers(void) {
       g_free(mainw->pulsed->abufs[i]);
     }
   }
+  g_free(mainw->pulsed->abufs);
 #endif
 }
 
@@ -2045,10 +2045,6 @@ gboolean start_audio_stream(void) {
   gchar *astname=g_strdup_printf("livesaudio-%d.pcm",getpid());
   gchar *astname_out=g_strdup_printf("livesaudio-%d.stream",getpid());
 
-  gchar *astreamer;
-
-  gchar *com;
-
   int arate=0;
 
   int afd;
@@ -2076,15 +2072,17 @@ gboolean start_audio_stream(void) {
 #endif
     }
 
-    astreamer=g_build_filename(prefs->lib_dir,PLUGIN_EXEC_DIR,PLUGIN_AUDIO_STREAM,playername,NULL);
-    com=g_strdup_printf("%s play %d \"%s\" \"%s\" %d",astreamer,mainw->vpp->audio_codec,astream_name,astream_name_out,arate);
 
   astream_pid=fork();
 
   if (!astream_pid) {
     // mkfifo and play until killed
+    gchar *astreamer=g_build_filename(prefs->lib_dir,PLUGIN_EXEC_DIR,PLUGIN_AUDIO_STREAM,playername,NULL);
+    gchar *com=g_strdup_printf("%s play %d \"%s\" \"%s\" %d",astreamer,mainw->vpp->audio_codec,astream_name,astream_name_out,arate);
     
     setsid(); // create new session id
+
+    g_free(astreamer);
     
     // block here until killed
 
@@ -2112,8 +2110,6 @@ gboolean start_audio_stream(void) {
 #endif
   }
 
-  g_free(astreamer);
-  g_free(com);
   g_free(astream_name);
   g_free(astream_name_out);
 
@@ -2142,13 +2138,13 @@ void stop_audio_stream(void) {
 
     if (prefs->audio_player==AUD_PLAYER_PULSE) {
 #ifdef HAVE_PULSE_AUDIO
-      close(mainw->pulsed->astream_fd);
+      if (mainw->pulsed->astream_fd>-1) close(mainw->pulsed->astream_fd);
       mainw->pulsed->astream_fd=-1;
 #endif
     }
     if (prefs->audio_player==AUD_PLAYER_JACK) {
 #ifdef ENABLE_JACK
-      close(mainw->jackd->astream_fd);
+      if (mainw->jackd->astream_fd>-1) close(mainw->jackd->astream_fd);
       mainw->jackd->astream_fd=-1;
 #endif
     }
