@@ -1,6 +1,6 @@
 // callbacks.h
 // LiVES
-// (c) G. Finch <salsaman@xs4all.nl> 2003 - 2010
+// (c) G. Finch <salsaman@xs4all.nl,salsaman@gmail.com> 2003 - 2011
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -28,6 +28,10 @@ void
 on_open_loc_activate                      (GtkMenuItem     *menuitem,
 					   gpointer         user_data);
 
+void
+on_open_utube_activate                      (GtkMenuItem     *menuitem,
+					     gpointer         user_data);
+
 void
 on_stop_clicked                         (GtkMenuItem     *menuitem,
                                          gpointer         user_data);
@@ -200,6 +204,10 @@ void
 on_location_select                   (GtkButton       *button,
 				      gpointer         user_data);
 
+void
+on_utube_select                   (GtkButton       *button,
+				   gpointer         user_data);
+
 void
 on_autoreload_toggled                (GtkToggleButton *togglebutton,
 				 gpointer         user_data);
