@@ -1,6 +1,6 @@
 // yuv4mpeg.c
 // LiVES
-// (c) G. Finch 2004 - 2010 <salsaman@xs4all.nl>
+// (c) G. Finch 2004 - 2010 <salsaman@xs4all.nl,salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING or www.gnu.org for licensing details
 
@@ -256,13 +256,12 @@ void weed_layer_set_from_yuv4m (weed_plant_t *layer, file *sfile) {
   weed_set_int_value(layer,"current_palette",WEED_PALETTE_YUV420P);
   weed_set_int_value(layer,"YUV_subspace",WEED_YUV_SUBSPACE_YCBCR);
 
+  create_empty_pixel_data(layer,FALSE,TRUE);
+
   if (!yuv4mpeg->ready) {
-    create_empty_pixel_data(layer,FALSE);
     return;
   }
 
-  create_empty_pixel_data(layer,FALSE);
-
   yuv4mpeg->pixel_data=weed_get_voidptr_array(layer,"pixel_data",&error);
 
   // create a thread to open the stream header
