@@ -1,6 +1,6 @@
 // mainwindow.h
 // LiVES (lives-exe)
-// (c) G. Finch <salsaman@xs4all.nl> 2003 - 2011
+// (c) G. Finch <salsaman@xs4all.nl,salsaman@gmail.com> 2003 - 2011
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -488,6 +488,9 @@ typedef struct {
   GtkWidget *open_vcd;
   GtkWidget *open_dvd;
   GtkWidget *open_loc;
+  GtkWidget *open_utube;
+  GtkWidget *open_loc_menu;
+  GtkWidget *open_loc_submenu;
   GtkWidget *open_yuv4m;
   GtkWidget *open_lives2lives;
   GtkWidget *send_lives2lives;
