@@ -378,11 +378,35 @@ static void check_clear_all_button (void) {
 
 
 
+
+static gboolean read_perkey_defaults(int kfd, int key, int mode, int version) {
+  gboolean ret=TRUE;
+  int nparams;
+  size_t bytes=read(kfd,&nparams,sizint);
+
+  if (nparams>65536) {
+    g_printerr("Too many params, file is probably broken.\n");
+    return FALSE;
+  }
+
+  if (bytes<sizint) {
+    return FALSE;
+  }
+
+  if (nparams>0) {
+    ret=read_key_defaults(kfd,nparams,key,mode,version);
+  }
+  return ret;
+}
+
+
+
+
 gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
   int modes=rte_getmodespk();
   int i;
   int kfd;
-  int version,nparams;
+  int version;
   int hlen;
   FILE *kfile=NULL;
   gchar *msg,*tmp;
@@ -566,20 +590,30 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
 
     if (key<1||key>prefs->rte_keys_virtual) {
       d_print((tmp=g_strdup_printf(_("Invalid key %d in %s\n"),key,keymap_file)));
+      g_printerr(tmp);
       g_free(tmp);
       notfound=TRUE;
       g_free(hashname);
+      if (keymap_file2!=NULL) {
+	// read param defaults
+	if (!read_perkey_defaults(kfd,-1,-1,version)) break;
+      }
       continue;
     }
 
     def_modes[key-1]++;
 
-
     if (strncmp(hashname,"Weed",4)||strlen(hashname)<5) {
       d_print((tmp=g_strdup_printf(_("Invalid effect %s in %s\n"),hashname,keymap_file)));
+      g_printerr(tmp);
       g_free(tmp);
       notfound=TRUE;
       g_free(hashname);
+      if (keymap_file2!=NULL) {
+	// read param defaults
+	if (!read_perkey_defaults(kfd,-1,-1,version)) break;
+      }
+      def_modes[key-1]--;
       continue;
     }
 
@@ -589,8 +623,15 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
     if ((mode=weed_add_effectkey(key,whashname,TRUE))==-1) {
       // could not locate effect
       d_print((tmp=g_strdup_printf(_("Unknown effect %s in %s\n"),whashname,keymap_file)));
+      g_printerr(tmp);
+      g_free(tmp);
       notfound=TRUE;
       g_free(hashname);
+      if (keymap_file2!=NULL) {
+	// read param defaults
+	if (!read_perkey_defaults(kfd,-1,-1,version)) break;
+      }
+      def_modes[key-1]--;
       continue;
     }
 
@@ -598,12 +639,24 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
 
     if (mode==-2){
       d_print((tmp=g_strdup_printf(_("This version of LiVES cannot mix generators/non-generators on the same key (%d) !\n"),key)));
+      g_printerr(tmp);
       g_free(tmp);
+      if (keymap_file2!=NULL) {
+	// read param defaults
+	if (!read_perkey_defaults(kfd,-1,-1,version)) break;
+      }
+      def_modes[key-1]--;
       continue;
     }
     if (mode==-3){
       d_print((tmp=g_strdup_printf(_("Too many effects bound to key %d.\n"),key)));
+      g_printerr(tmp);
       g_free(tmp);
+      if (keymap_file2!=NULL) {
+	// read param defaults
+	if (!read_perkey_defaults(kfd,-1,-1,version)) break;
+      }
+      def_modes[key-1]--;
       continue;
     }
     if (rte_window!=NULL) {
@@ -612,17 +665,9 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
       type_label_set_text(key-1,mode);
     }
 
-
     if (keymap_file2!=NULL) {
       // read param defaults
-      bytes=read(kfd,&nparams,sizint);
-      if (bytes<sizint) {
-	eof=TRUE;
-	break;
-      }
-      if (nparams>0) {
-	read_key_defaults(kfd,nparams,key-1,def_modes[key-1],version);
-      }
+      if (!read_perkey_defaults(kfd,key-1,def_modes[key-1],version)) break;
     }
   }
 
@@ -706,7 +751,7 @@ on_rte_info_clicked (GtkButton *button, gpointer user_data) {
 
   gtk_container_set_border_width (GTK_CONTAINER (rte_info_window), 40);
   gtk_window_set_transient_for(GTK_WINDOW(rte_info_window),GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(button))));
-  gtk_window_set_position (GTK_WINDOW (rte_info_window), GTK_WIN_POS_CENTER);
+  gtk_window_set_position (GTK_WINDOW (rte_info_window), GTK_WIN_POS_CENTER_ALWAYS);
   gtk_window_set_default_size (GTK_WINDOW (rte_info_window), RTE_INFO_WIDTH, RTE_INFO_HEIGHT);
 
   gtk_widget_show(rte_info_window);
@@ -1225,9 +1270,9 @@ GtkWidget * create_rte_window (void) {
       list=name_type_list;
       
       while (list!=NULL) {
-	weed_plant_t *filter=get_weed_filter(weed_get_idx_for_hashname(g_list_nth_data(hash_list,fx_idx),FALSE));
+	weed_plant_t *filter=get_weed_filter(weed_get_idx_for_hashname(g_list_nth_data(hash_list,fx_idx),TRUE));
 	int filter_flags=weed_get_int_value(filter,"flags",&error);
-	if ((enabled_in_channels(filter,FALSE)>1&&!has_video_chans_in(filter,FALSE))||(weed_plant_has_leaf(filter,"host_menu_hide")&&weed_get_boolean_value(filter,"host_menu_hide",&error)==WEED_TRUE)||(filter_flags&WEED_FILTER_IS_CONVERTER)) {
+	if ((weed_plant_has_leaf(filter,"plugin_unstable")&&weed_get_boolean_value(filter,"plugin_unstable",&error)==WEED_TRUE&&!prefs->unstable_fx)||((enabled_in_channels(filter,FALSE)>1&&!has_video_chans_in(filter,FALSE))||(weed_plant_has_leaf(filter,"host_menu_hide")&&weed_get_boolean_value(filter,"host_menu_hide",&error)==WEED_TRUE)||(filter_flags&WEED_FILTER_IS_CONVERTER))) {
 	  list = list->next;
 	  fx_idx++;
 	  continue; // skip audio transitions and hidden entries
@@ -1552,7 +1597,7 @@ void load_default_keymap(void) {
   gchar *keymap_template=g_strdup_printf("%s%sdefault.keymap",prefs->prefix_dir,DATA_DIR);
   gchar *com,*tmp;
 
-  pthread_mutex_lock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
   if (!g_file_test (keymap_file, G_FILE_TEST_EXISTS)) {
     com=g_strdup_printf("/bin/cp %s %s",keymap_template,keymap_file);
     dummyvar=system(com);
@@ -1564,11 +1609,11 @@ void load_default_keymap(void) {
     g_free(tmp);
     g_free(keymap_file);
     g_free(keymap_template);
-    pthread_mutex_unlock(&mainw->gtk_mutex);
+    threaded_dialog_spin();
     return;
   }
   on_load_keymap_clicked(NULL,NULL);
   g_free(keymap_file);
   g_free(keymap_template);
-  pthread_mutex_unlock(&mainw->gtk_mutex);
+  threaded_dialog_spin();
 }
