@@ -1,6 +1,6 @@
 // stream.c
 // LiVES
-// (c) G. Finch 2008 - 2010 <salsaman@xs4all.nl>
+// (c) G. Finch 2008 - 2010 <salsaman@xs4all.nl,salsaman@gmail.com>
 // released under the GNU GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -817,6 +817,9 @@ void weed_layer_set_from_lives2lives(weed_plant_t *layer, gint clip, lives_vstre
 	// ...free old pixel_data
 	int i,np=weed_leaf_num_elements(layer,"pixel_data");
 	pixel_data=weed_get_voidptr_array(layer,"pixel_data",&error);
+	if (weed_plant_has_leaf(layer,"host_pixel_data_contiguous") && 
+	    weed_get_boolean_value(layer,"host_pixel_data_contiguous",&error)==WEED_TRUE)
+	  np=1;
 	for (i=0;i<np;i++) {
 	  g_free(pixel_data[i]);
 	}
@@ -831,7 +834,7 @@ void weed_layer_set_from_lives2lives(weed_plant_t *layer, gint clip, lives_vstre
       weed_set_int_value(layer,"height",lstream->vsize);
       weed_set_int_value(layer,"current_palette",lstream->palette);
       weed_set_int_value(layer,"YUV_clamping",lstream->YUV_clamping);
-      create_empty_pixel_data(layer,FALSE);
+      create_empty_pixel_data(layer,FALSE,TRUE);
     }
 
     pixel_data=weed_get_voidptr_array(layer,"pixel_data",&error);
